==> rest-assured-1.5-sources.jar: com/jayway/restassured/internal/filter/FilterContextImpl.java <==
package com.jayway.restassured.internal.filter;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class FilterContextImpl
  extends java.lang.Object  implements
    com.jayway.restassured.filter.FilterContext,    groovy.lang.GroovyObject {
public FilterContextImpl
(java.lang.String path, groovyx.net.http.Method method, java.lang.Object assertionClosure, java.util.List<com.jayway.restassured.filter.Filter> filterList) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getAssertionClosure() { return null;}
public  void setAssertionClosure(java.lang.Object value) { }
public  java.lang.Object getProperties() { return null;}
public  void setProperties(java.lang.Object value) { }
public  com.jayway.restassured.response.Response next(com.jayway.restassured.specification.FilterableRequestSpecification request, com.jayway.restassured.specification.FilterableResponseSpecification response) { return (com.jayway.restassured.response.Response)null;}
public  java.lang.String getRequestPath() { return (java.lang.String)null;}
public  groovyx.net.http.Method getRequestMethod() { return (groovyx.net.http.Method)null;}
public  com.jayway.restassured.response.Response send(com.jayway.restassured.specification.RequestSender requestSender) { return (com.jayway.restassured.response.Response)null;}
public  void setValue(java.lang.String name, java.lang.Object value) { }
public  java.lang.Object getValue(java.lang.String name) { return null;}
}

==> rest-assured-1.7.2-sources.jar: com/jayway/restassured/internal/filter/FilterContextImpl.java <==
package com.jayway.restassured.internal.filter;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class FilterContextImpl
  extends java.lang.Object  implements
    com.jayway.restassured.filter.FilterContext,    groovy.lang.GroovyObject {
public FilterContextImpl
(java.lang.String completePath, java.lang.String path, com.jayway.restassured.internal.http.Method method, java.lang.Object assertionClosure, java.util.List<com.jayway.restassured.filter.Filter> filterList) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getAssertionClosure() { return null;}
public  void setAssertionClosure(java.lang.Object value) { }
public  java.lang.Object getProperties() { return null;}
public  void setProperties(java.lang.Object value) { }
public  com.jayway.restassured.response.Response next(com.jayway.restassured.specification.FilterableRequestSpecification request, com.jayway.restassured.specification.FilterableResponseSpecification response) { return (com.jayway.restassured.response.Response)null;}
public  java.lang.String getRequestPath() { return (java.lang.String)null;}
public  com.jayway.restassured.internal.http.Method getRequestMethod() { return (com.jayway.restassured.internal.http.Method)null;}
public  java.lang.String getCompleteRequestPath() { return (java.lang.String)null;}
public  com.jayway.restassured.response.Response send(com.jayway.restassured.specification.RequestSender requestSender) { return (com.jayway.restassured.response.Response)null;}
public  void setValue(java.lang.String name, java.lang.Object value) { }
public  java.lang.Object getValue(java.lang.String name) { return null;}
}
